@@ -38,10 +38,12 @@ struct _IPMisc{
 
 int IPMisc_Init(IPMisc *m);
 
-/** Singleton */
+void IpMiscMapping_Update(void);
 
-int IpMiscSingleton_Init(ConfigFileInfo *ConfigInfo);
+/** Mapping */
 
-int IPMiscSingleton_Process(IHeader *h /* Entity followed */);
+int IpMiscMapping_Init(ConfigFileInfo *ConfigInfo);
+
+int IPMiscMapping_Process(MsgContext *MsgCtx);
 
 #endif // IPMISC_H_INCLUDED
