@@ -5,9 +5,9 @@
 #include "common.h"
 #include "iheader.h"
 
-#define PRINTON		Log_Inited()
+#define PRINTON     Log_Inited()
 
-#define DEBUGSECTION	if( PRINTON && Log_DebugOn() )
+#define DEBUGSECTION    if( Log_DebugOn() )
 
 int Log_Init(ConfigFileInfo *ConfigInfo, BOOL PrintScreen, BOOL Debug);
 
@@ -17,10 +17,10 @@ BOOL Log_DebugOn(void);
 
 void Log_Print(const char *Type, const char *format, ...);
 
-#define	WARNING(...)    Log_Print("WARN", __VA_ARGS__)
-#define	INFO(...)       Log_Print("INFO", __VA_ARGS__)
-#define	ERRORMSG(...)   Log_Print("ERROR", __VA_ARGS__)
-#define	DEBUG(...)      DEBUGSECTION \
+#define ERRORMSG(...)   Log_Print("ERROR", __VA_ARGS__)
+#define WARNING(...)    Log_Print("WARN", __VA_ARGS__)
+#define INFO(...)       Log_Print("INFO", __VA_ARGS__)
+#define DEBUG(...)      DEBUGSECTION \
                             Log_Print("DEBUG", __VA_ARGS__);
 
 void ShowRefusingMessage(IHeader *h, const char *Message);
