@@ -1,7 +1,7 @@
 #ifndef PIPES_H_INCLUDED
 #define PIPES_H_INCLUDED
 
-#ifdef WIN32
+#ifdef _WIN32
     #include <windows.h>
 
     #define PIPE_HANDLE HANDLE
@@ -9,7 +9,7 @@
     #define CREATE_PIPE(rh_ptr, wh_ptr) CreatePipe((rh_ptr), (wh_ptr), NULL, 0)
 
     #define CREATE_PIPE_SUCCEEDED(ret) ((ret) != 0)
-#else /* WIN32 */
+#else /* _WIN32 */
     #include <sys/types.h>
     #include <sys/stat.h>
     #include <fcntl.h>
@@ -25,6 +25,6 @@
 
     #define READ_PIPE(fd, buf, len)     read((fd), (buf), (len))
 
-#endif /* WIN32 */
+#endif /* _WIN32 */
 
 #endif // PIPES_H_INCLUDED
