@@ -1,7 +1,7 @@
 #include <stdio.h>
 
 
-#ifdef WIN32
+#ifdef _WIN32
 #include <windows.h>
 
 int main(void)
