@@ -16,7 +16,11 @@ struct _UdpM {
     EFFECTIVE_LOCK  Lock;
 
     ThreadHandle    WorkThread;
+    ThreadHandle    SwepThread;
 
+    int IsServer;
+
+    const char      *ServiceName;
     AddressList     AddrList;
     struct { /* parallel query informations */
         /* When these two are not NULL, parallel-query is enabled */
@@ -29,7 +33,7 @@ struct _UdpM {
 
     /* public */
     int (*Send)(UdpM *m,
-                IHeader *h, /* Entity followed */
+                const char *Buffer,
                 int BufferLength
                 );
 };
